# Knowledgenet
Knowledgenet is a Python Language software library that enables application developers to build applications that make complex decisions based on **facts** supplied to the service entrypoint and **rules** developed by **application developers** and **business users**. Knowledgenet is an implementation of an **Inference Engine** using an adaptation of the Rete algorithm designed by **Charles L. Forgy** of Carnegie Melon University. Rete is an efficient pattern matching algorithm that is widely used in many AI systems including Expert Systems.

We are working on creating more documents. In the meantime, please refer to the documentation in [Knowledgenet Repository](https://github.com/amitchatterjee/knowledgenet/tree/develop/doc).

